@@ -71,18 +71,19 @@ my $mmdp = new  Algorithm::Evolutionary::Fitness::MMDP;
 # no es realmente necesario ya que este algoritmo define ambos operadores por
 # defecto. Los parámetros son la función de fitness, la tasa de selección y los
 # operadores de variación.
-#my $fitness = sub { $mmdp->apply(@_) };
+my $fitness = sub { $mmdp->apply(@_) };
 
-my $generation = Algorithm::Evolutionary::Op::Easy->new( $mmdp , $selection_rate , [$m, $c] ) ;
+my $generation = Algorithm::Evolutionary::Op::Easy->new( $fitness , $selection_rate , [$m, $c] ) ;
 
 #Time
 my $inicioTiempo = [gettimeofday()];
 
 #----------------------------------------------------------#
 for ( @pop ) {
-    if ( !defined $_->Fitness() ) {
-	$_->evaluate( $mmdp );
-    }
+  if ( !defined $_->Fitness() ) {
+    my $this_fitness = $fitness->($_);
+    $_->Fitness( $this_fitness );
+  }
 }
 
 my $contador=0;
@@ -117,10 +118,10 @@ Contributed by Pedro Castillo Valdivieso, modified by J. J. Merelo
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2009/07/24 08:46:58 $ 
-  $Header: /media/Backup/Repos/opeal/opeal/Algorithm-Evolutionary/examples/mmdp.pl,v 3.0 2009/07/24 08:46:58 jmerelo Exp $ 
+  CVS Info: $Date: 2008/02/16 17:36:19 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/examples/mmdp.pl,v 1.2 2008/02/16 17:36:19 jmerelo Exp $ 
   $Author: jmerelo $ 
-  $Revision: 3.0 $
+  $Revision: 1.2 $
   $Name $
 
 =cut
