@@ -25,9 +25,6 @@ Tide , and outputs the x and y coordinates, along with fitness. Best
 fitness is close to 1. Around 50 generations should be enough, but
 default is population and number of generations equal to 100.
 
-This script includes also a test of the consensus function (shown as "C" in output),
-which is used in some types of algorithms. 
-
 =cut
 
 use warnings;
@@ -122,10 +119,10 @@ Contributed by Pedro Castillo Valdivieso, modified by J. J. Merelo
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2012/05/15 11:58:01 $ 
-  $Header: /media/Backup/Repos/opeal/opeal/Algorithm-Evolutionary/examples/p_peaks.pl,v 3.1 2012/05/15 11:58:01 jmerelo Exp $ 
+  CVS Info: $Date: 2008/06/16 16:31:28 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/examples/p_peaks.pl,v 1.5 2008/06/16 16:31:28 jmerelo Exp $ 
   $Author: jmerelo $ 
-  $Revision: 3.1 $
+  $Revision: 1.5 $
   $Name $
 
 =cut
