@@ -44,30 +44,18 @@ for ( 0..$conf->{'pop_size'} ) {
   push( @pop, $indi );
 }
 
+
 #----------------------------------------------------------#
+# Variation operators
+my $m =  new Algorithm::Evolutionary::Op::Mutation( $conf->{'mutation'}->{'rate'}, $conf->{'mutation'}->{'priority'}  );
+my $c = new Algorithm::Evolutionary::Op::Crossover($conf->{'mutation'}->{'points'}, $conf->{'crossover'}->{'priority'} );
+
 # Fitness function
 my $fitness_class = "Algorithm::Evolutionary::Fitness::".$conf->{'fitness'}->{'class'};
 eval  "require $fitness_class" || die "Can't load $fitness_class: $@\n";
 my @params = $conf->{'fitness'}->{'params'}? @{$conf->{'fitness'}->{'params'}} : ();
 my $fitness_object = eval $fitness_class."->new( \@params )" || die "Can't instantiate $fitness_class: $@\n";
 
-#----------------------------------------------------------#
-# Variation operators
-my @ops;
-for my $o ( keys %{$conf->{'ops'}} ) {
-    my $op_class = "Algorithm::Evolutionary::Op::".$o;
-    eval  "require $op_class" || die "Can't load $op_class: $@\n";
-    my @params = @{$conf->{'ops'}->{$o}};
-    my $op_object = eval $op_class.'->new( @params )' || die "Can't instantiate $op_class: $@\n";
-#    my $m =  new Algorithm::Evolutionary::Op::Mutation( $conf->{'mutation'}->{'rate'}, $conf->{'mutation'}->{'priority'}  );
-#my $c = new Algorithm::Evolutionary::Op::Crossover($conf->{'crossover'}->{'points'}, $conf->{'crossover'}->{'priority'} );
-    ####################### Big hack #######################################3
-    if ( ref $op_object eq 'Algorithm::Evolutionary::Op::Novelty_Mutation' ) {
-      $op_object->{'_population_hashref'} = $fitness_object->{'_cache'};
-    }
-    push @ops, $op_object;
-}
-
 #----------------------------------------------------------#
 #Usamos estos operadores para definir una generación del algoritmo. Lo cual
 # no es realmente necesario ya que este algoritmo define ambos operadores por
@@ -75,7 +63,7 @@ for my $o ( keys %{$conf->{'ops'}} ) {
 # operadores de variación.
 my $fitness = sub { $fitness_object->apply(@_) };
 
-my $generation = Algorithm::Evolutionary::Op::Easy->new( $fitness , $conf->{'selection_rate'} , \@ops ) ;
+my $generation = Algorithm::Evolutionary::Op::Easy->new( $fitness , $conf->{'selection_rate'} , [$m, $c] ) ;
 
 #Time
 my $inicioTiempo = [gettimeofday()];
@@ -120,10 +108,10 @@ J. J. Merelo, C<jj@merelo.net>
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2009/07/24 08:46:58 $ 
-  $Header: /media/Backup/Repos/opeal/opeal/Algorithm-Evolutionary/examples/run_easy_ga.pl,v 3.0 2009/07/24 08:46:58 jmerelo Exp $ 
+  CVS Info: $Date: 2008/02/17 17:02:55 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/examples/run_easy_ga.pl,v 1.2 2008/02/17 17:02:55 jmerelo Exp $ 
   $Author: jmerelo $ 
-  $Revision: 3.0 $
+  $Revision: 1.2 $
   $Name $
 
 =cut
