@@ -1,7 +1,6 @@
 use strict; # -*- cperl -*-
 use warnings;
 
-use lib qw( ../../../../lib );
 
 =head1 NAME
 
@@ -23,7 +22,7 @@ ONEMAX is the classical count-ones optimization function. Fast to implement, and
 
 package Algorithm::Evolutionary::Fitness::ONEMAX;
 
-our ($VERSION) = ( '$Revision: 3.0 $ ' =~ / (\d+\.\d+)/ ) ;
+our $VERSION = ( '$Revision: 1.2 $ ' =~ /(\d+\.\d+)/ ) ;
 
 use Carp qw( croak );
 use base qw(Algorithm::Evolutionary::Fitness::String);
@@ -48,11 +47,10 @@ sub onemax {
     if ( defined $cache->{$string} ) {
 	return $cache->{$string};
     }
-    my $num_ones = ($string =~ tr/1/1/);
-#    my $num_ones = grep( $_, split(//, $string ));
-#     while ( $string ) {
-#       $num_ones += chop( $string );
-#     }
+    my $num_ones;
+    while ( $string ) {
+      $num_ones += chop( $string );
+    }
     $cache->{$string} = $num_ones;
     return $num_ones;
 }
@@ -62,10 +60,11 @@ sub onemax {
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2009/07/24 08:46:59 $ 
-  $Header: /media/Backup/Repos/opeal/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Fitness/ONEMAX.pm,v 3.0 2009/07/24 08:46:59 jmerelo Exp $ 
+  CVS Info: $Date: 2008/06/23 11:27:10 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Fitness/ONEMAX.pm,v 1.2 2008/06/23 11:27:10 jmerelo Exp $ 
   $Author: jmerelo $ 
-  $Revision: 3.0 $
+  $Revision: 1.2 $
+  $Name $
 
 =cut
 
