@@ -1,7 +1,6 @@
 use strict; # -*- cperl -*-
 use warnings;
 
-use lib qw( ../../../../lib );
 
 =head1 NAME
 
@@ -17,10 +16,7 @@ Algorithm::Evolutionary::Fitness::String - Base class for string-based fitness f
 
 =head1 DESCRIPTION
 
-Base class for fitness functions applied to string-based chromosomes;
-extracts common code, and saves time. Provides a hash called C<%cache>
-to be used as a, well, cache for evaluations. Assumes it's using the
-C<_str> instance variable of the chromosome 
+Base class for fitness functions applied to string-based chromosomes; extracts common code, and saves time. Provides a hash called C<%cache> to be used as a, well, cache for evaluations.
 
 =head1 METHODS
 
@@ -28,7 +24,7 @@ C<_str> instance variable of the chromosome
 
 package Algorithm::Evolutionary::Fitness::String;
 
-our $VERSION =  '3.0' ;
+our $VERSION = ( '$Revision: 1.1 $ ' =~ /(\d+\.\d+)/ ) ;
 
 use Carp qw( croak );
 use base qw(Algorithm::Evolutionary::Fitness::Base);
@@ -56,7 +52,7 @@ Applies the instantiated problem to a chromosome, delegating to a specific funct
 sub _apply {
     my $self = shift;
     my $individual = shift;
-    return  $self->_really_apply( $individual->{'_str'});
+    return  $self->_really_apply( $individual->{_str});
 }
 
 =head2 _really_apply( $string )
@@ -69,11 +65,9 @@ sub _really_apply {
   croak "This should be overriden";
 }
 
-=head2 cached_evals()
+=head2 cached_evals
 
-Returns the number of keys in the evaluation cache, which can be
-compared to the total number of evaluations to find the cache hit
-rate. 
+Returns the number of keys in the evaluation cache
 
 =cut
 
@@ -87,6 +81,12 @@ sub cached_evals {
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
+  CVS Info: $Date: 2008/06/23 11:27:10 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Fitness/String.pm,v 1.1 2008/06/23 11:27:10 jmerelo Exp $ 
+  $Author: jmerelo $ 
+  $Revision: 1.1 $
+  $Name $
+
 =cut
 
-"Theory";
+"What???";
