@@ -23,7 +23,7 @@ Algorithm::Evolutionary::Individual::Base - Base class for chromosomes that know
 
 =head1 DESCRIPTION
 
-Base class for individuals in evolutionary computation algorithms
+Base class for individuals, that is, "chromosomes" in evolutionary computation algorithms. However, chromosomes needn't be bitstrings, so the name is a bit misleading. This is, however, an "empty" base class, that acts as a boilerplate for deriving others. 
 
 =cut
 
@@ -31,10 +31,12 @@ package Algorithm::Evolutionary::Individual::Base;
 
 use XML::Parser;
 use XML::Parser::EasyTree;
+use YAML qw(Dump Load LoadFile);
 use Carp;
 
-our ($VERSION) = ( '$Revision: 1.2 $ ' =~ /(\d+\.\d+)/ );
+our ($VERSION) = ( '$Revision: 1.6 $ ' =~ /(\d+\.\d+)/ );
 
+use constant MY_OPERATORS => qw(None);
 
 =head1 METHODS 
 
@@ -198,6 +200,17 @@ sub asXML {
   return $str;
 }
 
+=head2 as_yaml
+
+Prints it as YAML. 
+
+=cut
+
+sub as_yaml {
+  my $self = shift;
+  return Dump($self);
+}
+
 =head2 Atom
 
 Sets or gets the value of an atom. Each individual is divided in atoms, which
@@ -224,6 +237,36 @@ sub Fitness {
   return $self->{_fitness};
 }
 
+=head2 my_operators
+
+Operators that can act on this data structure. Returns an array with the names of the known operators
+
+=cut
+
+sub my_operators {
+    my $self = shift;
+    return $self->MY_OPERATORS;
+}
+
+=head2 evaluate( $fitness )
+
+Evaluates using the $fitness function given. Can be a Fitness object or a ref-to-sub
+
+=cut
+
+sub evaluate {
+  my $self = shift;
+  my $fitness_func = shift || croak "Need a fitness function";
+  if ( ref $fitness_func eq 'CODE' ) {
+      return $self->Fitness( $fitness_func->($self) );
+  } elsif (  ( ref $fitness_func ) =~ 'Fitness' ) {
+      return $self->Fitness( $fitness_func->apply($self) );
+  } else {
+      croak "$fitness_func is can't be used to evaluate";
+  }
+
+}
+
 =head2 Chrom
 
 Sets or gets the chromosome itself, that is, the data
@@ -238,6 +281,7 @@ sub Chrom {
   croak "To be implemented in derived classes!";
 }
 
+
 =head1 Known subclasses
 
 =over 4
@@ -261,10 +305,10 @@ L<Algorithm::Evolutionary::Individual::Tree>
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2008/06/18 17:18:11 $ 
-  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Individual/Base.pm,v 1.2 2008/06/18 17:18:11 jmerelo Exp $ 
+  CVS Info: $Date: 2008/06/22 12:18:52 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Individual/Base.pm,v 1.6 2008/06/22 12:18:52 jmerelo Exp $ 
   $Author: jmerelo $ 
-  $Revision: 1.2 $
+  $Revision: 1.6 $
   $Name $
 
 =cut
