@@ -1,9 +1,9 @@
-use strict; #-*-cperl-*-
+use strict;
 use warnings;
 
 =head1 NAME
 
-Tree - A Direct Acyclic Graph, or tree, useful for Genetic Programming-Style stuff
+     Tree - A Direct Acyclic Graph, or tree, useful for Genetic Programming-Style stuff
 
 =head1 SYNOPSIS
 
@@ -31,9 +31,8 @@ L<Algorithm::Evolutionary::Individual::Base|Algorithm::Evolutionary::Individual:
 
 =head1 DESCRIPTION
 
-Tree-like individual for genetic programming. Uses direct acyclic graphs
-as representation for trees, which is very convenient. This class has
-not been tested extensively, so it might not work.
+Array individual for a genetic programming. Uses Direct Acyclic graphs as
+representation for trees, which is very convenient. 
 
 =cut
 
@@ -42,7 +41,7 @@ package Algorithm::Evolutionary::Individual::Tree;
 use Carp;
 use Exporter;
 
-our ($VERSION) = ( '$Revision: 3.1 $ ' =~ / (\d+\.\d+)/ );
+our ($VERSION) = ( '$Revision: 1.1.1.1 $ ' =~ /(\d+\.\d+)/ );
 
 use Tree::DAG_Node;
 
@@ -52,18 +51,17 @@ our @ISA = qw (Algorithm::Evolutionary::Individual::Base);
 
 =head1 METHODS
 
-=head2 new( $primitives, $depth, $fitness )
+=head2 new
 
-Creates a new tree using a primitives hashref, max depth, and a
-ref-to-fitness 
+Creates a new tree
 
 =cut
 
 sub new {
   my $class = shift; 
   my $self = {_primitives => shift,
-	      _depth => shift,
-	      _fitness => undef };
+			  _depth => shift,
+			  _fitness => undef };
   my @keys = keys %{$self->{_primitives}};
   $self->{_keys} = \@keys;
   bless $self, $class;
@@ -167,12 +165,6 @@ sub asString {
   return $str;
 }
 
-=head2 nodePrint
-
-Prints a node
-
-=cut
-
 sub nodePrint {
   my $node = shift;
   my $options = shift;
@@ -188,12 +180,6 @@ sub nodePrint {
   
 }
 
-=head2 closeParens
-
-Internal subrutine: closes node parenthesis
-
-=cut 
-
 sub closeParens {
   my $node = shift;
   my $options = shift;
@@ -207,18 +193,6 @@ sub closeParens {
  
 }
 
-
-=head2 Atom
-
-Returns the tree, which is atomic by itself. Cannot be used as lvalue
-
-=cut
-
-sub Atom {
-  my $self = shift;
-  return $self->{'_tree'};
-}
-
 =head2 asXML
 
 Prints it as XML. It prints the tree as String, which does not mean
@@ -236,13 +210,7 @@ sub asXML {
   return $str.$str2."\n</indi>";
 }
 
-
-=head2 addAtom
-
-Dummy sub
-
-=cut 
-
+#Dummy sub
 sub addAtom {
   my $self = shift;
   $self->{_tree} = Tree::DAG_Node->new();
@@ -308,26 +276,16 @@ sub growSubTree {
   }
 }
 
-=head2 size()
-
-Returns 1, since it's got only 1 Atom
-
-=cut
-
-sub size {
-  my $self = shift;
-  return 1;
-}
 
 =head1 Copyright
   
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2009/07/28 11:30:56 $ 
-  $Header: /media/Backup/Repos/opeal/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Individual/Tree.pm,v 3.1 2009/07/28 11:30:56 jmerelo Exp $ 
+  CVS Info: $Date: 2008/02/12 17:49:39 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Individual/Tree.pm,v 1.1.1.1 2008/02/12 17:49:39 jmerelo Exp $ 
   $Author: jmerelo $ 
-  $Revision: 3.1 $
+  $Revision: 1.1.1.1 $
   $Name $
 
 =cut
