@@ -1,9 +1,9 @@
-use strict;  #-*-cperl-*-
+use strict;
 use warnings;
 
 =head1 NAME
 
-Algorithm::Evolutionary::Individual::Vector - Array as an individual for evolutionary computation
+    Algorithm::Evolutionary::Individual::Vector - Array as an individual for evolutionary computation
 
 =head1 SYNOPSIS
 
@@ -34,7 +34,7 @@ Algorithm::Evolutionary::Individual::Vector - Array as an individual for evoluti
     tie my @vector, 'Algorithm::Evolutionary::Individual::Vector', @array;
     print tied( @vector )->asXML();
 
-    print $indi3->as_string(); #Prints the individual
+    print $indi3->asString(); #Prints the individual
     print $indi3->asXML() #Prints it as XML. See L<XML> for more info on this
 
 =head1 Base Class
@@ -54,13 +54,15 @@ package Algorithm::Evolutionary::Individual::Vector;
 use Carp;
 use Exporter;
 
-our ($VERSION) = ( '$Revision: 3.2 $ ' =~ / (\d+\.\d+)/ );
+our ($VERSION) = ( '$Revision: 1.1.1.1 $ ' =~ /(\d+\.\d+)/ );
 
-use base 'Algorithm::Evolutionary::Individual::Base';
+use Algorithm::Evolutionary::Individual::Base;
+
+our @ISA = qw (Algorithm::Evolutionary::Individual::Base);
 
 =head1 METHODS 
 
-=head2 new( [$length = 10] [, $start_of_range = 0] [, $end_of_range = 1] )
+=head2 new
 
 Creates a new random array individual, with fixed initial length, and uniform distribution
 of values within a range
@@ -81,17 +83,6 @@ sub new {
   return $self;
 }
 
-=head2 size()
-
-Returns vector size (dimension)
-
-=cut
-
-sub size {
-  my $self = shift;
-  return $self->{'_length'};
-}
-
 sub TIEARRAY {
   my $class = shift; 
   my $self = { _array => \@_,
@@ -101,7 +92,7 @@ sub TIEARRAY {
   return $self;
 }
 
-=head2 set( $ref_to_hash )
+=head2 set
 
 Sets values of an individual; takes a hash as input. The array is
 initialized to a null array, and the start and end range are
@@ -121,7 +112,7 @@ sub set {
   $self->{_fitness} = undef;
 }
 
-=head2 randomize()
+=head2 randomize
 
 Assigns random values to the elements
 
@@ -209,7 +200,7 @@ sub FETCHSIZE {
   return @{$self->{_array}} -1;
 }
 
-=head2 length()
+=head2 length
 
 Returns the number of atoms in the individual
 
@@ -220,7 +211,7 @@ sub length {
   return scalar @{$self->{_array}};
 }
 
-=head2 fromString( $string )
+=head2 fromString
 
 Similar to a copy ctor; creates a vector individual from a string composed of 
 stuff separated by a separator
@@ -238,7 +229,7 @@ sub fromString  {
   return $self;
 }
 
-=head2 clone()
+=head2 clone
 
 Similar to a copy ctor: creates a new individual from another one
 
@@ -256,34 +247,22 @@ sub clone {
 }
 
 
-=head2 asString()
+=head2 asString
 
-Returns a string with chromosome plus fitness. OK, this is a bit confusing
+Prints it
 
 =cut
 
 sub asString {
   my $self = shift;
-  my $str = $self->as_string();
+  my $str = join( ", ", @{$self->{_array}}) . " -> ";
   if ( defined $self->{_fitness} ) {
-	$str .=", " . $self->{_fitness};
+	$str .=$self->{_fitness};
   }
   return $str;
 }
 
-=head2 as_string()
-
-Returns just the chromosome, not the fitness
-
-=cut
-
-sub as_string {
-  my $self = shift;
-  my $str = join( ", ", @{$self->{_array}});
-  return $str;
-}
-
-=head2 asXML()
+=head2 asXML
 
 Prints it as XML. See the L<Algorithm::Evolutionary::XML|lgorithm::Evolutionary::XML> OPEAL manual for details.
 
@@ -297,7 +276,7 @@ sub asXML {
   return $str."\n</indi>";
 }
 
-=head2 Chrom( [$ref_to_array]
+=head2 Chrom
 
 Sets or gets the array that holds the chromosome. Not very nice, and
 I would never ever do this in C++
@@ -317,9 +296,10 @@ sub Chrom {
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2011/11/23 10:59:47 $ 
-  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Individual/Vector.pm,v 3.2 2011/11/23 10:59:47 jmerelo Exp $ 
+  CVS Info: $Date: 2008/02/12 17:49:39 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Individual/Vector.pm,v 1.1.1.1 2008/02/12 17:49:39 jmerelo Exp $ 
   $Author: jmerelo $ 
-  $Revision: 3.2 $
+  $Revision: 1.1.1.1 $
+  $Name $
 
 =cut
