@@ -1,14 +1,22 @@
-use strict; #-*-cperl-*-
+use strict;
 use warnings;
 
-use lib qw( ../../lib ../../../lib ../../../../lib);
-
 =head1 NAME
 
-Algorithm::Evolutionary::Op::Bitflip - Bit-flip mutation
+  Algorithm::Evolutionary::Op::Bitflip - BitFlip mutation
 
 =head1 SYNOPSIS
 
+  my $xmlStr2=<<EOC; #howMany should be integer
+  <op name='Bitflip' type='unary' rate='0.5' >
+    <param name='howMany' value='2' /> 
+  </op>
+  EOC
+  my $ref2 = XMLin($xmlStr2);
+
+  my $op2 = Algorithm::Evolutionary::Op::Base->fromXML( $ref2 );
+  print $op2->asXML(), "\n*Arity ", $op->arity(), "\n";
+
   my $op = new Algorithm::Evolutionary::Op::Bitflip 2; #Create from scratch with default rate
 
 =head1 Base Class
@@ -24,19 +32,21 @@ does not need a rate
 
 =cut
 
+
 package Algorithm::Evolutionary::Op::Bitflip;
 
-our ($VERSION) = ( '$Revision: 3.4 $ ' =~ /(\d+\.\d+)/ );
+our ($VERSION) = ( '$Revision: 1.1.1.1 $ ' =~ /(\d+\.\d+)/ );
+
 
 use Carp;
-use Clone qw(clone);
 
-use base 'Algorithm::Evolutionary::Op::Base';
+use Algorithm::Evolutionary::Op::Base;
+our @ISA = qw(Algorithm::Evolutionary::Op::Base);
 
 #Class-wide constants
+our $APPLIESTO =  'Algorithm::Evolutionary::Individual::BitString';
 our $ARITY = 1;
-
-=head2 new( [$how_many] [,$priority] )
+=head2 new
 
 Creates a new mutation operator with a bitflip application rate, which defaults to 0.5,
 and an operator application rate (general for all ops), which defaults to 1.
@@ -53,7 +63,7 @@ sub new {
   return $self;
 }
 
-=head2 create()
+=head2 create
 
 Creates a new mutation operator.
 
@@ -66,11 +76,11 @@ sub create {
   return $self;
 }
 
-=head2 apply( $chromosome )
+=head2 apply
 
 Applies mutation operator to a "Chromosome", a bitstring, really. Can be
-applied only to I<victims> composed of [0,1] atoms, independently of representation; but 
-it checks before application that the operand is of type
+applied only to I<victims> with the C<_str> instance variable; but
+it checks before application that both operands are of type
 L<BitString|Algorithm::Evolutionary::Individual::BitString>.
 
 =cut
@@ -78,23 +88,13 @@ L<BitString|Algorithm::Evolutionary::Individual::BitString>.
 sub apply ($;$){
   my $self = shift;
   my $arg = shift || croak "No victim here!";
-#  my $victim = $arg->clone();
-  my $victim; 
-  if ( (ref $arg ) =~ /BitString/ ) {
-    $victim = clone( $arg );
-  } else {
-    $victim = $arg->clone();
-  }
-  my $size =  $victim->size();
-#  croak "Incorrect type ".(ref $victim) if ! $self->check( $victim );
-  croak "Too many changes" if $self->{_howMany} >= $size;
-  my @bits = 0..($size-1); # Hash with all bits
+  my $victim = $arg->clone();
+  croak "Incorrect type ".(ref $victim) if ! $self->check( $victim );
   for ( my $i = 0; $i < $self->{_howMany}; $i++ ) {
-      my $rnd = int (rand( @bits ));
-      my $who = splice(@bits, $rnd, 1 );
-      $victim->Atom( $who, $victim->Atom( $who )?0:1 );
+	my $rnd = int (rand( length( $victim->{_str} ) ));
+	$victim->Atom( $rnd, $victim->Atom( $rnd )?0:1 );
   }
-  $victim->{'_fitness'} = undef ;
+  $victim->Fitness(undef); #Invalidate fitness
   return $victim;
 }
 
@@ -103,5 +103,11 @@ sub apply ($;$){
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
+  CVS Info: $Date: 2008/02/12 17:49:38 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/Bitflip.pm,v 1.1.1.1 2008/02/12 17:49:38 jmerelo Exp $ 
+  $Author: jmerelo $ 
+  $Revision: 1.1.1.1 $
+  $Name $
+
 =cut
 
