@@ -1,16 +1,22 @@
 use strict;
 use warnings;
 
-use lib qw( ../../../../lib ); # mainly to avoid syntax errors when saving
-
 =head1 NAME
 
-Algorithm::Evolutionary::Op::CX (Cycle crossover) - 2-point crossover operator; Builds offspring in such a way
+    Algorithm::Evolutionary::Op::CX (Cycle crossover) - 2-point crossover operator; Builds offspreing in such a way
     that each gene comes from one of the parents. Preserves the absolute position of the elements 
     in the parent sequence
 
 =head1 SYNOPSIS
 
+  my $xmlStr3=<<EOC;
+  <op name='CX' type='binary' rate='1' />
+  EOC
+  my $ref3 = XMLin($xmlStr3);
+
+  my $op3 = Algorithm::Evolutionary::Op::Base->fromXML( $ref3 );
+  print $op3->asXML(), "\n";
+
   my $op4 = new Algorithm::Evolutionary::Op::CX 3;
 
   my $indi = new Algorithm::Evolutionary::Individual::Vector 10;
@@ -24,14 +30,14 @@ L<Algorithm::Evolutionary::Op::Base|Algorithm::Evolutionary::Op::Base>
 
 =head1 DESCRIPTION
 
-Cycle Crossover operator for a GA. It is applied to chromosomes that are
+Cycle Crossover operator for a GA. It applies to chromosomes that are
 a permutation of each other; even as the class it applies to is
 L<Algorithm::Evolutionary::Individual::Vector>, it will issue lots of
 "La jodimos!" messages if the parents do not fulfill this condition. 
 
 Some information on this operator can be obtained from
-L<this
-evolutionary computation tutorial|http://www.cs.bham.ac.uk/~rmp/slide_book/node4.html#SECTION00444300000000000000>
+L<http://www.cs.bham.ac.uk/~rmp/slide_book/node4.html#SECTION00444300000000000000|this
+evolutionary computation tutorial>
 
 =head1 METHODS
 
@@ -39,16 +45,18 @@ evolutionary computation tutorial|http://www.cs.bham.ac.uk/~rmp/slide_book/node4
 
 package Algorithm::Evolutionary::Op::CX;
 
-our $VERSION = '3.2';
+our ($VERSION) = ( '$Revision: 1.1.1.1 $ ' =~ /(\d+\.\d+)/ );
 
 use Carp;
 
-use base 'Algorithm::Evolutionary::Op::Base';
+use Algorithm::Evolutionary::Op::Base;
+our @ISA = ('Algorithm::Evolutionary::Op::Base');
 
 #Class-wide constants
 our $APPLIESTO =  'Algorithm::Evolutionary::Individual::Vector';
 our $ARITY = 2;
 
+
 =head2 new
 
 Creates a new Algorithm::Evolutionary::Op::CX operator.
@@ -82,7 +90,7 @@ sub create {
 Applies Algorithm::Evolutionary::Op::CX operator to a "Chromosome", a bitstring, really. Can be
 applied only to I<victims> with the C<_bitstring> instance variable; but
 it checks before application that both operands are of type
-L<Individual::Vector|Algorithm::Evolutionary::Individual::Vector>.
+L<Algorithm::Evolutionary::Individual::Vector|Algorithm::Evolutionary::Individual::Vector>.
 
 =cut
 
@@ -112,35 +120,38 @@ sub  apply ($$;$){
 #  print "CX \$leng = $leng\n";
   $changed=$i=0;
   while ($changed <  $leng ) {   
-    my $found=0;
-    #Looking for the next element in cycle
-    for ($j=0; $j < $leng ; $j++) { 
-      if ( $p1->Atom($j) == $p2->Atom($i)) {  
-	$found=$j;
-	last;
-      }
-    }
+	my $found=0;
+	#Looking for the next element in cycle
+	for ($j=0; $j < $leng ; $j++) { 
+	  if ( $p1->Atom($j) == $p2->Atom($i)) {  
+		$found=$j;
+		last;
+	  }
+	}
     #Look if the next element in cycle  was found
     if ($found) { 
-      $child->Atom($found, $p1->Atom($found));
-      #	  print "Found $found valor ", $child->Atom($found),  "\n";
-      $i=$found;
-      $changed++;
-    }
-    else { #End of the cycle, get the genes from the second parent
-      $child->Atom(0, $p1->Atom(0) ); $changed++;
-      for ($i=1;( $i < $leng ) && ( $changed < $leng )  ; $i++) { 
-	if ($child->Atom($i) eq $no ) { 
-	  #		  print "Cambiando $i valor ", $p2->Atom($i),  "\n";
-	  $child->Atom($i,$p2->Atom($i));
+	  $child->Atom($found, $p1->Atom($found));
+#	  print "Found $found valor ", $child->Atom($found),  "\n";
+	  $i=$found;
 	  $changed++;
 	}
-      }
-    }
+    else { #End of the cycle, get the genes from the second parent
+	  $child->Atom(0, $p1->Atom(0) ); $changed++;
+	  for ($i=1;( $i < $leng ) && ( $changed < $leng )  ; $i++) { 
+		if ($child->Atom($i) eq $no ) { 
+#		  print "Cambiando $i valor ", $p2->Atom($i),  "\n";
+		  $child->Atom($i,$p2->Atom($i));
+		  $changed++;
+		}
+	  }
+	}
   }#End-while
   map( $visto{$_}++,@{$child->{_array}} ); 
   for (keys %visto) { 
-	if ($visto{$_} ne 2 ) {
+	if ($visto{$_} > 2 ) {
+	  print "La jodimos!\n";
+	}
+	if ($visto{$_} < 2 ) {
 	  print "La jodimos!\n";
 	}
 	#print "$_ visto $visto{$_}\n";
@@ -150,7 +161,7 @@ sub  apply ($$;$){
 	  print "Messed up!\n";
 	}
   }
-  return $child; #return Child, explicative comment if I've ever seen one
+  return $child; #return Child
 }
 
 =head1 Copyright
@@ -158,4 +169,10 @@ sub  apply ($$;$){
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
+  CVS Info: $Date: 2008/02/12 17:49:39 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/CX.pm,v 1.1.1.1 2008/02/12 17:49:39 jmerelo Exp $ 
+  $Author: jmerelo $ 
+  $Revision: 1.1.1.1 $
+  $Name $
+
 =cut
