@@ -3,7 +3,7 @@ use warnings;
 
 =head1 NAME
 
-Algorithm::Evolutionary::Op::ChangeLengthMutation - Increases/decreases by one atom the length of the string
+  Algorithm::Evolutionary::Op::ChangeLengthMutation - Increases/decreases by one the length of the string
 
 =head1 SYNOPSIS
 
@@ -32,21 +32,23 @@ eliminating it.
 
 package Algorithm::Evolutionary::Op::ChangeLengthMutation;
 
-our ($VERSION) = ( '$Revision: 3.1 $ ' =~ /(\d+\.\d+)/ );
+our ($VERSION) = ( '$Revision: 1.1.1.1 $ ' =~ /(\d+\.\d+)/ );
+
 
 use Carp;
 
-use base 'Algorithm::Evolutionary::Op::Base';
+use Algorithm::Evolutionary::Op::Base;
+our @ISA = qw(Algorithm::Evolutionary::Op::Base);
 
 #Class-wide constants
 our $APPLIESTO =  'Algorithm::Evolutionary::Individual::String';
 our $ARITY = 1;
 
-=head2 new( $rate[, $increment_probability] [, $decrement_probability]
+=head2 new
 
 Creates a new operator. It is called with 3 arguments: the rate it's
 going to be applied, and the probability of adding and substracting an
-element from the string each time it's applied.
+element from the string each time it's applied. Rates default to one.
 
 =cut
 
@@ -56,9 +58,8 @@ sub new {
   my $probplus = shift || 1;
   my $probminus = shift || 1;
   my $self = { rate => $rate, 
-	       _probplus => $probplus,
-	       _probminus => $probminus };
-
+			   _probplus => $probplus,
+			   _probminus => $probminus };
   bless $self, $class;
   return $self;
 }
@@ -86,9 +87,9 @@ sub create {
 =head2 apply
 
 This is the function that does the stuff. The probability of adding
-and substracting are normalized. Depending on a random draw, a random
+and subsctracting are normalized. Depending on a random draw, a random
 char is added to the string (at the end) or eliminated from a random
-position within the string..
+position within the string.
 
 =cut
 
@@ -118,10 +119,10 @@ sub apply ($$){
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2009/09/13 12:49:04 $ 
-  $Header: /media/Backup/Repos/opeal/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/ChangeLengthMutation.pm,v 3.1 2009/09/13 12:49:04 jmerelo Exp $ 
+  CVS Info: $Date: 2008/02/12 17:49:39 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/ChangeLengthMutation.pm,v 1.1.1.1 2008/02/12 17:49:39 jmerelo Exp $ 
   $Author: jmerelo $ 
-  $Revision: 3.1 $
+  $Revision: 1.1.1.1 $
   $Name $
 
 =cut
