@@ -3,8 +3,9 @@ use warnings;
 
 =head1 NAME
 
-Algorithm::Evolutionary::Op::Crossover - n-point crossover
-    operator; puts fragments of the second operand into the first operand
+  Algorithm::Evolutionary::Op::Crossover - n-point crossover
+    operator; puts a part of the second operand into the first
+    operand; can be 1 or 2 points.
              
 
 =head1 SYNOPSIS
@@ -18,12 +19,14 @@ Algorithm::Evolutionary::Op::Crossover - n-point crossover
   my $op3 = Algorithm::Evolutionary::Op::Base->fromXML( $xmlStr3 );
   print $op3->asXML(), "\n";
 
-  #Apply to 2 Individuals of the String class
+  #Apply to 2 Individuals. Could be String.
   my $indi = new Algorithm::Evolutionary::Individual::BitString 10;
+  my $indi2 = $indi->clone();
+  my $indi3 = $indi->clone();
   my $offspring = $op3->apply( $indi2, $indi3 ); #$indi2 == $offspring
 
   #Initialize using OO interface
-  my $op4 = new Algorithm::Evolutionary::Op::Crossover 2; #Crossover with 2 crossover points
+  my $op4 = new Algorithm::Evolutionary::Op::Crossover 3; #Crossover with 3 crossover points
 
 =head1 Base Class
 
@@ -38,32 +41,27 @@ their descendants
 for L<Algorithm::Evolutionary::Individual::Vector|Individual::Vector>
 would be  L<Algorithm::Evolutionary::Op::VectorCrossover|Op::VectorCrossover>
 
+
 =head1 METHODS
 
 =cut
 
 package Algorithm::Evolutionary::Op::Crossover;
 
-use lib qw(../../..);
+our ($VERSION) = ( '$Revision: 1.1.1.1 $ ' =~ /(\d+\.\d+)/ );
 
-our $VERSION =   sprintf "%d.%03d", q$Revision: 3.2 $ =~ /(\d+)\.(\d+)/g; # Hack for avoiding version mismatch
-
-use Clone qw(clone);
 use Carp;
 
-use base 'Algorithm::Evolutionary::Op::Base';
+use Algorithm::Evolutionary::Op::Base;
+our @ISA = ('Algorithm::Evolutionary::Op::Base');
 
 #Class-wide constants
 our $APPLIESTO =  'Algorithm::Evolutionary::Individual::String';
 our $ARITY = 2;
-our %parameters = ( numPoints => 2 );
 
-=head2 new( [$options_hash] [, $operation_priority] )
+=head2 new
 
-Creates a new n-point crossover operator, with 2 as the default number
-of points, that is, the default would be
-    my $options_hash = { numPoints => 2 };
-    my $priority = 1;
+Creates a new n-point crossover operator, with 2 as the default number of points
 
 =cut
 
@@ -71,11 +69,26 @@ sub new {
   my $class = shift;
   my $hash = { numPoints => shift || 2 };
   my $rate = shift || 1;
-  my $self = Algorithm::Evolutionary::Op::Base::new( $class, $rate, $hash );
+  my $self = Algorithm::Evolutionary::Op::Base::new( __PACKAGE__, $rate, $hash );
   return $self;
 }
 
-=head2 apply( $chromsosome_1, $chromosome_2 )
+=head2 create
+
+Creates a new 1 or 2 point crossover operator. But this is just to have a non-empty chromosome
+Defaults to 2 point
+
+=cut
+
+sub create {
+  my $class = shift;
+  my $self;
+  $self->{_numPoints} = shift || 2;
+  bless $self, $class;
+  return $self;
+}
+
+=head2 apply
 
 Applies xover operator to a "Chromosome", a string, really. Can be
 applied only to I<victims> with the C<_str> instance variable; but
@@ -83,15 +96,18 @@ it checks before application that both operands are of type
 L<BitString|Algorithm::Evolutionary::Individual::String>.
 
 Changes the first parent, and returns it. If you want to change both
-parents at the same time, check L<QuadXOver|Algorithm::Evolutionary::Op::QuadXOver>
+parents at the same time, check L<Algorithm::Evolutionary::Op:QuadXOver|Algorithm::Evolutionary::Op:QuadXOver>
+
 
 =cut
 
 sub  apply ($$$){
   my $self = shift;
   my $arg = shift || croak "No victim here!";
-  my $victim = clone( $arg );
+  my $victim = $arg->clone();
   my $victim2 = shift || croak "No victim here!";
+  croak "Incorrect type ".(ref $victim) if !$self->check($victim);
+  croak "Incorrect type ".(ref $victim2) if !$self->check($victim2);
   my $minlen = (  length( $victim->{_str} ) >  length( $victim2->{_str} ) )?
 	 length( $victim2->{_str} ): length( $victim->{_str} );
   my $pt1 = int( rand( $minlen ) );
@@ -103,33 +119,19 @@ sub  apply ($$$){
   }
   
   substr( $victim->{_str}, $pt1, $range ) = substr( $victim2->{_str}, $pt1, $range );
-  $victim->{'_fitness'} = undef;
+  $victim->Fitness( undef );
   return $victim; 
 }
 
-=head1 SEE ALSO
-
-=over 4
-
-=item L<Algorithm::Evolutionary::Op::QuadXOver> for pass-by-reference xover
-
-=item L<Algorithm::Evolutionary::Op::Uniform_Crossover> another more mutation-like xover
-
-=item L<Algorithm::Evolutionary::Op::Gene_Boundary_Crossover> don't disturb the building blocks!
-
-=item L<Algorithm::Evolutionary::Op::Uniform_Crossover_Diff> vive la difference!
-
-=back
-
 =head1 Copyright
   
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2011/02/14 06:55:36 $ 
-  $Header: /media/Backup/Repos/opeal/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/Crossover.pm,v 3.2 2011/02/14 06:55:36 jmerelo Exp $ 
+  CVS Info: $Date: 2008/02/12 17:49:39 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/Crossover.pm,v 1.1.1.1 2008/02/12 17:49:39 jmerelo Exp $ 
   $Author: jmerelo $ 
-  $Revision: 3.2 $
+  $Revision: 1.1.1.1 $
   $Name $
 
 =cut
