@@ -32,11 +32,16 @@ to the target as the differente indicated.
 package Algorithm::Evolutionary::Op::DeltaTerm;
 use Carp;
 
-our ($VERSION) = ( '$Revision: 3.0 $ ' =~ / (\d+\.\d+)/ ) ;
+our $VERSION = ( '$Revision: 1.1.1.1 $ ' =~ /(\d+\.\d+)/ ) ;
 
-use base 'Algorithm::Evolutionary::Op::Base';
+use Algorithm::Evolutionary::Op::Base;
+our @ISA = qw(Algorithm::Evolutionary::Op::Base);
 
-=head2 new( $target[, $delta] )
+# Class-wide constants
+our $APPLIESTO =  'ARRAY';
+our $ARITY = 1;
+
+=head2 new
 
 Creates a new terminator. Takes as parameters the target and the
 epsilon (or delta, whatever you want to call it): 
@@ -47,8 +52,8 @@ epsilon (or delta, whatever you want to call it):
 
 Delta can be 0, which means that application of this operator will
 return true only when the first element fitness is the same as the
-target. Use this judiciously when your fitness is a floating
-point number.
+target. Use this judiciously when your fitness is floating
+point.
 
 =cut
 
@@ -63,14 +68,14 @@ sub new {
 }
 
 
-=head2 apply( $population )
+=head2 apply 
 
 Will return true while the difference between the fitness of the first element 
 in the population and the target is less than C<$delta>, true otherwise
 
     $dt->apply( \@pop ) == 1 
 
-if the target has not been reached. Population must be sorted before this.
+if the target has not been reached
 
 =cut
 
@@ -84,12 +89,12 @@ sub apply ($) {
   
 =head1 See Also
 
-L<Algorithm::Evolutionary::Op::FullAlgorithm> needs an object of this class to check
+L<Algorithm::Evolutionary::Op::EzFullAlgo|Algorithm::Evolutionary::Op::EZFullAlgo> needs an object of this class to check
 for the termination condition. It's normally used alongside "generation-type"
-objects such as L<Algorithm::Evolutionary::Op::Easy>.
+objects such as L<Algorithm::Evolutionary::Op::EasyAlgorithm|EasyAlgorithm> or  L<Algorithm::Evolutionary::Op::ParallelAlgorithm|ParallelAlgorithm> 
 
 There are other options for termination conditions: L<Algorithm::Evolutionary::Op::NoChangeTerm|Algorithm::Evolutionary::Op::NoChangeTerm> and  
-L<Algorithm::Evolutionary::Op::GenerationalTerm>.
+L<Algorithm::Evolutionary::Op::GenerationalTerm|Algorithm::Evolutionary::Op::GenerationalTerm> and  
 
 
 =head1 Copyright
@@ -97,8 +102,8 @@ L<Algorithm::Evolutionary::Op::GenerationalTerm>.
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2009/07/24 08:46:59 $ 
-  $Header: /media/Backup/Repos/opeal/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/DeltaTerm.pm,v 3.0 2009/07/24 08:46:59 jmerelo Exp $ 
+  CVS Info: $Date: 2008/02/12 17:49:39 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/DeltaTerm.pm,v 1.1.1.1 2008/02/12 17:49:39 jmerelo Exp $ 
   $Author: jmerelo $ 
 
 =cut
