@@ -1,18 +1,27 @@
 use strict;
 use warnings;
 
-use lib qw(../../..);
-
-=encoding utf8
-
 =head1 NAME
 
-Algorithm::Evolutionary::Op::GaussianMutation - Changes numeric chromosome components following the gaussian distribution.
+    Algorithm::Evolutionary::Op::GaussianMutation - Changes numeric chromosome components following the 
+                       gaussian distribution
+                     
+                 
 
 =cut
 
 =head1 SYNOPSIS
 
+  my $xmlStr4=<<EOC; # From XML
+  <op name='GaussianMutation' type='unary' rate='1'>
+    <param name='avg' value='0' />
+    <param name='stddev' value='0.1' />
+  </op>
+  EOC
+  my $ref4 = XMLin($xmlStr4);
+  my $op4 = Algorithm::Evolutionary::Op::Base->fromXML( $ref4 );
+  print $op4->asXML(), "\n";
+
   my $op = new Algorithm::Evolutionary::Op::GaussianMutation( 0, 0.05) # With average 0, and 0.05 standard deviation
 
 =cut
@@ -31,21 +40,21 @@ Mutation operator for a GA: applies gaussian mutation to a number
 
 package Algorithm::Evolutionary::Op::GaussianMutation;
 
-our $VERSION =   '3.4';
+our ($VERSION) = ( '$Revision: 1.1.1.1 $ ' =~ /(\d+\.\d+)/ );
 
 use Carp;
 use Math::Random;
-use Clone qw(clone);
 
-use base 'Algorithm::Evolutionary::Op::Base';
+use Algorithm::Evolutionary::Op::Base;
+our @ISA = ('Algorithm::Evolutionary::Op::Base');
 
 #Class-wide constants
 our $APPLIESTO =  'Algorithm::Evolutionary::Individual::Vector';
 our $ARITY = 1;
 
-=head2 new( [$average = 0] [, $standard deviation = 1] [, $rate = 1 ]
+=head2 new
 
-Creates a new mutation operator with an application rate. Rate defaults to 1.
+Creates a new mutation operator with an application rate. Rate defaults to 0.1.
 
 =cut
 
@@ -75,50 +84,44 @@ sub create {
   my $avg = shift || 0; 
   my $stddev = shift || 1;
   
+
   my $self = {_avg => $avg,
-	      _stddev => $stddev };
+			  _stddev => $stddev };
 
   bless $self, $class;
   return $self;
 }
 
-=head2 apply( $chromosome )
+=head2 apply
 
 Applies mutation operator to a "Chromosome", a vector of stuff,
 really. Can be applied only to I<victims> with the C<_array> instance
-variable; but it checks before application (roughly) that the operand is of
-type L<Algorithm::Evolutionary::Individual::Vector>.
+variable; but it checks before application that both operands are of
+type L<Algorithm::Evolutionary::Individual::Vector|Algorithm::Evolutionary::Individual::Vector>.
 
 =cut
 
 sub apply ($$) {
   my $self = shift;
   my $arg = shift || croak "No victim here!";
-  croak "Incorrect type".(ref $arg) if !$arg->{_array};
-  my $victim = clone($arg);
-  my @deltas = random_normal( @{$victim->{_array}} + 1,  #+1 is needed, returns empty if not
-			      $self->{_avg}, $self->{_stddev} );
+  my $victim = $arg->clone();
+  croak "Incorrect type ".(ref $victim) if !$self->check($victim);  
+  my @deltas = random_normal( @{$victim->{_array}} + 1, $self->{_avg}, $self->{_stddev} );
   for ( @{$victim->{_array}} ) {
-      my $adjust = pop @deltas;
-      $_ += $adjust;
-      # makes sure that the new value stays within its confines
-      if($_ < $victim->{_rangestart}) {
-	  $_ = $victim->{_rangestart};
-      } elsif($_ > $victim->{_rangeend}) {
-	  $_ = $victim->{_rangeend};
-      }
+	$_ += pop @deltas;
   }
-  $victim->{_fitness} = undef;
   return $victim;
 }
 
-=head1 THANKS
-
-This file has been improved with input from Christoph Meißner.
-
 =head1 Copyright
   
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
+  CVS Info: $Date: 2008/02/12 17:49:39 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/GaussianMutation.pm,v 1.1.1.1 2008/02/12 17:49:39 jmerelo Exp $ 
+  $Author: jmerelo $ 
+  $Revision: 1.1.1.1 $
+  $Name $
+
 =cut
