@@ -3,10 +3,9 @@ use warnings;
 
 =head1 NAME
 
-Algorithm::Evolutionary::Op::GeneralGeneration - Customizable single generation for an evolutionary algorithm.
+    Algorithm::Evolutionary::Op::GeneralGeneration - Customizable single generation for an evolutionary algorithm.
                  
 =head1 SYNOPSIS
-
   #Taken from the t/general.t file, verbatim
   my $m = new Algorithm::Evolutionary::Op::Bitflip; #Changes a single bit
   my $c = new Algorithm::Evolutionary::Op::Crossover; #Classical 2-point crossover
@@ -52,21 +51,18 @@ used, along with its priorities
 
 package Algorithm::Evolutionary::Op::GeneralGeneration;
 
-use lib qw(../../..);
-
-our $VERSION = '3.2';
+our $VERSION = ( '$Revision: 1.1.1.1 $ ' =~ /(\d+\.\d+)/ ) ;
 
 use Carp;
 
-use base 'Algorithm::Evolutionary::Op::Base';
-
-use Algorithm::Evolutionary::Wheel;
+use Algorithm::Evolutionary::Op::Base;
+our @ISA = qw(Algorithm::Evolutionary::Op::Base);
 
 # Class-wide constants
 our $APPLIESTO =  'ARRAY';
 our $ARITY = 1;
 
-=head2 new( $evaluation_function, $selector, $ref_to_operator_array, $replacement_rate )
+=head2 new
 
 Creates an algorithm, with the usual operators. Includes a default mutation
 and crossover, in case they are not passed as parameters
@@ -76,16 +72,16 @@ and crossover, in case they are not passed as parameters
 sub new {
   my $class = shift;
   my $self = {};
-  $self->{'_eval'} = shift || croak "No eval function found";
-  $self->{'_selector'} = shift || croak "No selector found";
-  $self->{'_ops'} = shift || croak "No operator found";
-  $self->{'_replacementRate'} = shift || 1; #Default to all  replaced
+  $self->{_eval} = shift || croak "No eval function found";
+  $self->{_selector} = shift || croak "No selector found";
+  $self->{_ops} = shift || croak "No operator found";
+  $self->{_replacementRate} = shift || 1; #Default to all  replaced
   bless $self, $class;
   return $self;
 }
 
 
-=head2 set( $ref_to_params_hash, $ref_to_code_hash, $ref_to_operators_hash )
+=head2 set
 
 Sets the instance variables. Takes a ref-to-hash as
 input
@@ -110,7 +106,7 @@ sub set {
   }
 }
 
-=head2 apply( $population )
+=head2 apply
 
 Applies the algorithm to the population, which should have
 been evaluated first; checks that it receives a
@@ -141,7 +137,7 @@ sub apply ($) {
   my $opWheel = new Algorithm::Evolutionary::Wheel @rates;
 
   my @newpop;
-  my $pringaos =  @$pop  * $self->{'_replacementRate'} ;
+  my $pringaos =  @$pop  * $self->{_replacementRate} ;
   for ( my $i = 0; $i < $pringaos; $i++ ) {
 	  my @offspring;
 	  my $selectedOp = $ops[ $opWheel->spin()];
@@ -158,38 +154,25 @@ sub apply ($) {
   #Eliminate and substitute
   splice( @$pop, -$pringaos );
   for ( @newpop ) {
-      $_->evaluate( $eval );
+	my $fitness = $self->{_eval}->( $_ );
+	$_->Fitness( $fitness );
   }
   push @$pop, @newpop;
-  my @sortPop = sort { $b->{'_fitness'} <=> $a->{'_fitness'}; } @$pop;
+  my @sortPop = sort { $b->{_fitness} <=> $a->{_fitness}; } @$pop;
   @$pop = @sortPop;
   
 }
 
-=head1 SEE ALSO
-
-=over 4
-
-=item *
-
-A more modern and flexible version: L<Algorithm::Evolutionary::Op::Generation_Skeleton>.
-
-=item * 
-
-L<Algorithm::Evolutionary::Op::CanonicalGA>.
-
-=item * 
-
-L<Algorithm::Evolutionary::Op::FullAlgorithm>.
-
-
-=back
-
 =head1 Copyright
-
   
-This file is released under the GPL. See the LICENSE file included in this distribution,
-or go to http://www.fsf.org/licenses/gpl.txt
+  This file is released under the GPL. See the LICENSE file included in this distribution,
+  or go to http://www.fsf.org/licenses/gpl.txt
+
+  CVS Info: $Date: 2008/02/12 17:49:39 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/GeneralGeneration.pm,v 1.1.1.1 2008/02/12 17:49:39 jmerelo Exp $ 
+  $Author: jmerelo $ 
+  $Revision: 1.1.1.1 $
+  $Name $
 
 =cut
 
