@@ -3,13 +3,21 @@ use warnings;
 
 =head1 NAME
 
-Algorithm::Evolutionary::Op::IncMutation - Increments/decrements by one the value of one of the components
+  Algorithm::Evolutionary::Op::IncMutation - Increments/decrements by one the value of one of the components
                 of the string, takes into account the char class
 
 =cut
 
 =head1 SYNOPSIS
 
+  my $xmlStr2=<<EOC;
+  <op name='IncMutation' type='unary' rate='0.5' />
+  EOC
+  my $ref2 = XMLin($xmlStr2);
+
+  my $op2 = Algorithm::Evolutionary::Op::Base->fromXML( $ref2 );
+  print $op2->asXML(), "\n*Arity ", $op->arity(), "\n";
+
   my $op = new Algorithm::Evolutionary::Op::IncMutation; #Create from scratch
 
 =head1 Base Class
@@ -27,20 +35,20 @@ L<Algorithm::Evolutionary::Op::Base|Algorithm::Evolutionary::Op::Base>
 
 package Algorithm::Evolutionary::Op::IncMutation;
 
-use lib qw(../../..);
+our ($VERSION) = ( '$Revision: 1.1.1.1 $ ' =~ /(\d+\.\d+)/ );
 
-our $VERSION =   sprintf "%d.%03d", q$Revision: 3.1 $ =~ /(\d+)\.(\d+)/g; # Hack for avoiding version mismatch
 
 use Carp;
-use Clone qw(clone);
 
-use base 'Algorithm::Evolutionary::Op::Base';
+use Algorithm::Evolutionary::Op::Base;
+our @ISA = qw(Algorithm::Evolutionary::Op::Base);
 
 #Class-wide constants
 our $APPLIESTO =  'Algorithm::Evolutionary::Individual::String';
 our $ARITY = 1;
 
-=head2 create()
+=head2 create
+
 
 Creates a new mutation operator.
 
@@ -53,7 +61,7 @@ sub create {
   return $self;
 }
 
-=head2 apply( $indiv )
+=head2 apply
 
 Applies mutation operator to a "Chromosome", a string, really. Can be
 applied only to I<victims> with the C<_str> instance variable; but
@@ -65,14 +73,14 @@ the array of chars used for coding the the string
     $xmen->apply( $strChrom ) # will change 'acgt' into 'aagt' or
 			      # 'aggt', for instance
 
-Issues an error if there is no C<_chars> array, which is needed for computing the next.
+Issues an error if there is no C<_chars> array.
 
 =cut
 
 sub apply ($;$){
   my $self = shift;
   my $arg = shift || croak "No victim here!";
-  my $victim = clone( $arg );
+  my $victim = $arg->clone();
   croak "Incorrect type ".(ref $victim) if ! $self->check( $victim );
   my $rnd = int (rand( length( $victim->{_str} ) ));
   my $char = $victim->Atom( $rnd );
@@ -96,6 +104,12 @@ sub apply ($;$){
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
+  CVS Info: $Date: 2008/02/12 17:49:39 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/IncMutation.pm,v 1.1.1.1 2008/02/12 17:49:39 jmerelo Exp $ 
+  $Author: jmerelo $ 
+  $Revision: 1.1.1.1 $
+  $Name $
+
 
 =cut
 
