@@ -1,11 +1,9 @@
 use strict;
 use warnings;
 
-use lib qw(../../..);
-
 =head1 NAME
 
-Algorithm::Evolutionary::Op::Inverover  - Michalewicz's inver-over Operator. 
+    Algorithm::Evolutionary::Op::Inverover  - Michalewicz\'s inver-over Operator. 
 
 =head1 SYNOPSIS
 
@@ -17,14 +15,14 @@ Algorithm::Evolutionary::Op::Inverover  - Michalewicz's inver-over Operator.
   my $op3 = Algorithm::Evolutionary::Op::Base->fromXML( $ref3 );
   print $op3->asXML(), "\n";
 
-  my $indi = new Algorithm::Evolutionary::Individual::BitString 10;
+  my $indi = new BinaryIndi 10;
   my $indi2 = $indi->clone();
   my $indi3 = $indi->clone();
   $op3->apply( $indi2, $indi3 );
 
 =head1 Base Class
 
-L<Algorithm::Evolutionary::Op::Base>
+L<Algorithm::Evolutionary::Op::Base|Algorithm::Evolutionary::Op::Base>
 
 =head1 DESCRIPTION
 
@@ -32,8 +30,9 @@ Inver-over operator for a GA. Created by Michalewicz et al., mainly
 for the travelling salesman problem. Takes two chromosomes, which are
 permutations of each other.
 
-There is some information on this operator in this interview
-with Michalewicz: L<http://www.dcs.napier.ac.uk/coil/news/feature48.html>. You can also download papers from his home page: L<http://www.cs.adelaide.edu.au/~zbyszek/Papers/>.
+There is some information on this operator in
+L<http://www.dcs.napier.ac.uk/coil/news/feature48.html|this interview
+with Michalewicz>. You can also download papers from L<http://www.coe.uncc.edu/~zbyszek/papers.html|his home page>.
 
 =head1 METHODS
 
@@ -41,17 +40,19 @@ with Michalewicz: L<http://www.dcs.napier.ac.uk/coil/news/feature48.html>. You c
 
 package Algorithm::Evolutionary::Op::Inverover;
 
-our ($VERSION) = ( '$Revision: 3.0 $ ' =~ /(\d+\.\d+)/ );
+our ($VERSION) = ( '$Revision: 1.1.1.1 $ ' =~ /(\d+\.\d+)/ );
 
 use Carp;
 
-use base 'Algorithm::Evolutionary::Op::Base';
+use Algorithm::Evolutionary::Op::Base;
+our @ISA = ('Algorithm::Evolutionary::Op::Base');
 
 #Class-wide constants
 our $APPLIESTO =  'Algorithm::Evolutionary::Individual::Vector';
 our $ARITY = 2;
 
-=head2 new( $rate )
+
+=head2 new
 
 Creates a new Algorithm::Evolutionary::Op::Inverover operator.
 
@@ -79,10 +80,12 @@ sub create {
   return $self;
 }
 
-=head2 apply( $first, $second )
+=head2 apply
 
-Applies Algorithm::Evolutionary::Op::Inverover operator to a
-    "Chromosome". Can be applied to anything with the Atom method. 
+Applies Algorithm::Evolutionary::Op::Inverover operator to a "Chromosome", a bitstring, really. Can be
+applied only to I<victims> with the C<_bitstring> instance variable; but
+it checks before application that both operands are of type
+L<Algorithm::Evolutionary::Individual::Vector|Algorithm::Evolutionary::Individual::Vector>.
 
 =cut
 
@@ -145,10 +148,10 @@ sub  apply ($$$){
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2009/07/24 08:46:59 $ 
-  $Header: /media/Backup/Repos/opeal/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/Inverover.pm,v 3.0 2009/07/24 08:46:59 jmerelo Exp $ 
+  CVS Info: $Date: 2008/02/12 17:49:38 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/Inverover.pm,v 1.1.1.1 2008/02/12 17:49:38 jmerelo Exp $ 
   $Author: jmerelo $ 
-  $Revision: 3.0 $
+  $Revision: 1.1.1.1 $
   $Name $  
 
 =cut
