@@ -31,11 +31,16 @@ you want to apply some fancy diversity operator
 
 package Algorithm::Evolutionary::Op::NoChangeTerm;
 
-our ($VERSION) = ( '$Revision: 3.0 $ ' =~ / (\d+\.\d+)/ ) ;
+our $VERSION = ( '$Revision: 1.1.1.1 $ ' =~ /(\d+\.\d+)/ ) ;
 
-use base 'Algorithm::Evolutionary::Op::Base';
+use Algorithm::Evolutionary::Op::Base;
+our @ISA = qw(Algorithm::Evolutionary::Op::Base);
 
-=head2 new( [$number_of_generations_without_change] )
+# Class-wide constants
+our $APPLIESTO =  'ARRAY';
+our $ARITY = 1;
+
+=head2 new
 
 Creates a new terminator. Takes as an argument the number of
 generations after which it will return false, which defaults to 10. 
@@ -53,7 +58,7 @@ sub new {
 }
 
 
-=head2 apply( $population )
+=head2 apply
 
 Checks if the first member of the population has the same fitness as before,
 and increments counter. The population I<should be ordered>
@@ -75,14 +80,6 @@ sub apply ($) {
   
 }
   
-=head1 See Also
-
-L<Algorithm::Evolutionary::Op::FullAlgorithm> needs an object of this class to check
-for the termination condition. It's normally used alongside "generation-type"
-objects such as L<Algorithm::Evolutionary::Op::Easy>.
-
-There are other options for termination conditions: L<Algorithm::Evolutionary::Op::DeltaTerm> and  
-L<Algorithm::Evolutionary::Op::GenerationalTerm>.
 
 
 =head1 Copyright
@@ -90,10 +87,10 @@ L<Algorithm::Evolutionary::Op::GenerationalTerm>.
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2009/07/24 08:46:59 $ 
-  $Header: /media/Backup/Repos/opeal/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/NoChangeTerm.pm,v 3.0 2009/07/24 08:46:59 jmerelo Exp $ 
+  CVS Info: $Date: 2008/02/12 17:49:39 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/NoChangeTerm.pm,v 1.1.1.1 2008/02/12 17:49:39 jmerelo Exp $ 
   $Author: jmerelo $ 
-  $Revision: 3.0 $
+  $Revision: 1.1.1.1 $
   $Name $
  
 =cut
