@@ -3,7 +3,8 @@ use warnings;
 
 =head1 NAME
 
-Algorithm::Evolutionary::Op::QuadXOver - N-point crossover operator that changes operands
+    Algorithm::Evolutionary::Op::QuadXOver - n-point crossover operator; puts a part of the second operand
+                into the first operand; can be 1 or 2 points.
 
                  
 
@@ -11,7 +12,7 @@ Algorithm::Evolutionary::Op::QuadXOver - N-point crossover operator that changes
 
   my $xmlStr3=<<EOC;
   <op name='QuadXOver' type='binary' rate='1'>
-    <param name='numPoints' value='2' /> #Max is 2, anyways
+    <param name='numPoints' value='3' /> #Max is 2, anyways
   </op>
   EOC
   my $ref3 = XMLin($xmlStr3);
@@ -21,10 +22,10 @@ Algorithm::Evolutionary::Op::QuadXOver - N-point crossover operator that changes
 
   my $indi = new Algorithm::Evolutionary::Individual::BitString 10;
   my $indi2 = $indi->clone();
-  my $indi3 = $indi->clone(); #Operands are modified, so better to clone them
+  my $indi3 = $indi->clone();
   $op3->apply( $indi2, $indi3 );
 
-  my $op4 = new Algorithm::Evolutionary::Op::QuadXOver 1; #QuadXOver with 1 crossover points
+  my $op4 = new Algorithm::Evolutionary::Op::QuadXOver 3; #QuadXOver with 3 crossover points
 
 =head1 Base Class
 
@@ -41,23 +42,21 @@ children from two parents
 
 package Algorithm::Evolutionary::Op::QuadXOver;
 
-use lib qw( ../../.. );
-
-our $VERSION =   sprintf "%d.1%02d", q$Revision: 3.4 $ =~ /(\d+)\.(\d+)/g; # Hack for avoiding version mismatch
+our ($VERSION) = ( '$Revision: 1.1.1.1 $ ' =~ /(\d+\.\d+)/ );
 
 use Carp;
 
-use base 'Algorithm::Evolutionary::Op::Crossover';
+use Algorithm::Evolutionary::Op::Crossover;
+our @ISA = ('Algorithm::Evolutionary::Op::Crossover');
 
 #Class-wide constants
 our $APPLIESTO =  'Algorithm::Evolutionary::Individual::String';
 our $ARITY = 2;
 
-=head2 apply( $parent_1, $parent_2 )
+=head2 apply
 
 Same as L<Algorithm::Evolutionary::Op::Crossover>, but changes
-parents, does not return anything; that is, $parent_1 and $parent_2
-interchange genetic material.
+parents, does not return anything
 
 =cut
 
@@ -65,23 +64,21 @@ sub  apply ($$){
   my $self = shift;
   my $victim = shift || croak "No victim here!";
   my $victim2 = shift || croak "No victim here!";
-#  croak "Incorrect type ".(ref $victim) if !$self->check($victim);
-#  croak "Incorrect type ".(ref $victim2) if !$self->check($victim2);
+  croak "Incorrect type ".(ref $victim) if !$self->check($victim);
+  croak "Incorrect type ".(ref $victim2) if !$self->check($victim2);
   my $minlen = (  length( $victim->{_str} ) >  length( $victim2->{_str} ) )?
 	 length( $victim2->{_str} ): length( $victim->{_str} );
-  my $pt1 = 1+int( rand( $minlen - 1 ) ); # first crossover point shouldn't be 0
-  my $range;
-  if ( $self->{_numPoints} > 1 ) {
-    $range= 1 + int( rand( $minlen  - $pt1 ) );
-  } else {
-    $range = $minlen - $pt1;
-  }
+  my $pt1 = int( rand( $minlen ) );
+  my $range = 1 + int( rand( $minlen  - $pt1 ) );
 #  print "Puntos: $pt1, $range \n";
+  if ( $self->{_numPoints} > 1 ) {
+	$range =  int ( rand( length( $victim->{_str} ) - $pt1 ) );
+  }
   my $str = $victim->{_str};
   substr( $victim->{_str}, $pt1, $range ) = substr( $victim2->{_str}, $pt1, $range );
   substr( $victim2->{_str}, $pt1, $range ) = substr( $str, $pt1, $range );
   $victim->Fitness( undef );
-  $victim2->Fitness( undef );
+  $victim->Fitness( undef );
   return undef; #As a warning that you should not expect anything
 }
 
@@ -90,10 +87,10 @@ sub  apply ($$){
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2010/12/08 17:34:22 $ 
-  $Header: /media/Backup/Repos/opeal/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/QuadXOver.pm,v 3.4 2010/12/08 17:34:22 jmerelo Exp $ 
+  CVS Info: $Date: 2008/02/12 17:49:39 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/QuadXOver.pm,v 1.1.1.1 2008/02/12 17:49:39 jmerelo Exp $ 
   $Author: jmerelo $ 
-  $Revision: 3.4 $
+  $Revision: 1.1.1.1 $
   $Name $
 
 =cut
