@@ -1,21 +1,19 @@
-use strict; #-*-cperl-*-
+use strict;
 use warnings;
 
-use lib qw( ../../../../lib );
-
 =head1 NAME
 
-Algorithm::Evolutionary::Op::RouletteWheel - Fitness-proportional selection, using a roulette wheel
+     Algorithm::Evolutionary::Op::RouletteWheel - Fitness-proportional selection, using a roulette wheel
 
 =head1 SYNOPSIS
 
-    use Algorithm::Evolutionary::Op::RouletteWheel;
+    use  Algorithm::Evolutionary::Op::RouletteWheel;
     my $popSize = 100;
     my $selector = new  Algorithm::Evolutionary::Op::RouletteWheel $popSize;
 
 =head1 Base Class
 
-L<Algorithm::Evolutionary::Op::Selector>
+L<Algorithm::Evolutionary::Op::Base|Algorithm::Evolutionary::Op::Base>
 
 =head1 DESCRIPTION
 
@@ -32,17 +30,18 @@ L<http://www.geatbx.com/docu/algselct.html#nameselectionrws|this GA tutorial>
 package  Algorithm::Evolutionary::Op::RouletteWheel;
 use Carp;
 
-our ($VERSION) = ( '$Revision: 3.0 $ ' =~ / (\d+\.\d+)/ ) ;
+our $VERSION = ( '$Revision: 1.1.1.1 $ ' =~ /(\d+\.\d+)/ ) ;
 
-use base 'Algorithm::Evolutionary::Op::Selector';
+use Algorithm::Evolutionary::Op::Base;
+our @ISA = qw(Algorithm::Evolutionary::Op::Base);
 
 use Algorithm::Evolutionary::Wheel;
 
 # Class-wide constants
-#our $APPLIESTO =  'ARRAY';
-#our $ARITY = 2; #Needs an array for input, a reference for output
+our $APPLIESTO =  'ARRAY';
+our $ARITY = 2; #Needs an array for input, a reference for output
 
-=head2 new( $output_population_size )
+=head2 new
 
 Creates a new roulette wheel selector
 
@@ -50,8 +49,10 @@ Creates a new roulette wheel selector
 
 sub new {
  my $class = shift;
- my $self = Algorithm::Evolutionary::Op::Selector::new($class,shift );
- return $self;
+  my $self = {};
+  $self->{_outputSize} = shift || croak "I need an output population size";
+  bless $self, $class;
+  return $self;
 }
 
 =head2 apply
@@ -83,20 +84,16 @@ sub apply (@) {
   return @output;
 }
 
-=head1 See Also
-
-L<Algorithm::Evolutionary::Op::TournamentSelect> is another option for
-selecting a pool of individuals
 
 =head1 Copyright
   
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2009/07/24 08:46:59 $ 
-  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/RouletteWheel.pm,v 3.0 2009/07/24 08:46:59 jmerelo Exp $ 
+  CVS Info: $Date: 2008/02/12 17:49:39 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/RouletteWheel.pm,v 1.1.1.1 2008/02/12 17:49:39 jmerelo Exp $ 
   $Author: jmerelo $ 
-  $Revision: 3.0 $
+  $Revision: 1.1.1.1 $
   $Name $
 
 =cut
