@@ -1,12 +1,10 @@
 use strict;
 use warnings;
 
-use lib qw( ../../../../lib ); # mainly to avoid syntax errors when saving
-
 =head1 NAME
 
-SimulatedAnnealing - An operator that performs the simulated annealing algorithm
-                          on an individual, using an external freezing schedule
+    SimulatedAnnealing - An operator that performs the simulated annealing algorithm
+                          on an individual, using an external freezer.
 
 =head1 SYNOPSIS
 
@@ -17,7 +15,7 @@ SimulatedAnnealing - An operator that performs the simulated annealing algorithm
 
 =head1 Base Class
 
-L<Algorithm::Evolutionary::Op::Base>
+L< Algorithm::Evolutionary::Op::Base| Algorithm::Evolutionary::Op::Base>
 
 =head1 DESCRIPTION
 
@@ -29,18 +27,15 @@ Simulated Annealing
 
 package Algorithm::Evolutionary::Op::SimulatedAnnealing;
 
-our $VERSION = '3.1';
+our $VERSION = ( '$Revision: 1.2 $ ' =~ /(\d+\.\d+)/ ) ;
 use Carp;
-
 use Algorithm::Evolutionary::Op::LinearFreezer;
-use base 'Algorithm::Evolutionary::Op::Base';
+use Algorithm::Evolutionary::Op::Base;
+our @ISA = qw( Algorithm::Evolutionary::Op::Base);
 
+=head2 new
 
-=head2 new( $evaluation_function, $change_operator, $freezer[,
-    $initial_temperature] [,$minimum_temperature]
-    [,$number_of_changes], [,$verbose] )
-
-Creates a simulated annealing object
+Creates a S.A. algorithm
 
 =cut
 
@@ -59,11 +54,9 @@ sub new {
   return $self;
 }
 
-=head2 run( $individual )
-
-Applies the algorithm to the individual, returns the resulting
-    individual when the min temperature is reached. Same as C<apply> in other operators
+=head2 apply
 
+Applies the algorithm to the individual
 
 =cut
 
@@ -128,4 +121,10 @@ sub run ($) {
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
+  CVS Info: $Date: 2008/02/17 13:34:54 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/SimulatedAnnealing.pm,v 1.2 2008/02/17 13:34:54 jmerelo Exp $ 
+  $Author: jmerelo $ 
+  $Revision: 1.2 $
+  $Name $
+
 =cut
