@@ -1,15 +1,12 @@
-use strict; #-*-cperl-*-
+use strict;
 use warnings;
 
-use lib qw( ../../../../lib );
-
 =head1 NAME
 
     Algorithm::Evolutionary::Op::TournamentSelect - Tournament selector, takes individuals from one population
                        and puts them into another
 
 =head1 SYNOPSIS
-
   my $popSize = 100;
   my $tournamentSize = 7;
   my $selector = new Algorithm::Evolutionary::Op::TournamentSelect $popSize, $tournamentSize;
@@ -17,7 +14,7 @@ use lib qw( ../../../../lib );
 
 =head1 Base Class
 
-L<Algorithm::Evolutionary::Op::Base|Algorithm::Evolutionary::Op::Selector>
+L<Algorithm::Evolutionary::Op::Base|Algorithm::Evolutionary::Op::Base>
 
 =head1 DESCRIPTION
 
@@ -34,23 +31,25 @@ the best.
 package Algorithm::Evolutionary::Op::TournamentSelect;
 use Carp;
 
-our ($VERSION) = ( '$Revision: 2.2 $ ' =~ / (\d+\.\d+)/ ) ;
+our $VERSION = ( '$Revision: 1.1.1.1 $ ' =~ /(\d+\.\d+)/ ) ;
 
-use base 'Algorithm::Evolutionary::Op::Base';
+use Algorithm::Evolutionary::Op::Base;
+our @ISA = qw(Algorithm::Evolutionary::Op::Base);
 
 # Class-wide constants
-#our $APPLIESTO =  'ARRAY';
-#our $ARITY = 2; #Needs an array for input, a reference for output
+our $APPLIESTO =  'ARRAY';
+our $ARITY = 2; #Needs an array for input, a reference for output
 
-=head2 new( $output_population_size, $tournament_size )
+=head2 new
 
 Creates a new tournament selector
 
 =cut
 
 sub new {
-  my $class = shift;
-  my $self = Algorithm::Evolutionary::Op::Selector::new($class, shift );
+ my $class = shift;
+  my $self = {};
+  $self->{_outputSize} = shift || croak "I need an output population size";
   $self->{_tournamentSize} = shift || 2;
   bless $self, $class;
   return $self;
@@ -86,8 +85,8 @@ sub apply (@) {
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2009/02/04 20:51:26 $ 
-  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/TournamentSelect.pm,v 2.2 2009/02/04 20:51:26 jmerelo Exp $ 
+  CVS Info: $Date: 2008/02/12 17:49:39 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/TournamentSelect.pm,v 1.1.1.1 2008/02/12 17:49:39 jmerelo Exp $ 
   $Author: jmerelo $ 
 
 =cut
