@@ -3,7 +3,7 @@ use warnings;
 
 =head1 NAME
 
-Algorithm::Evolutionary::Op::VectorCrossover - Crossover for L<Algorithm::Evolutionary::Individual::Vector>.
+    Algorithm::Evolutionary::Op::VectorCrossover - Crossover for L<Algorithm::Evolutionary::Individual::Vector>.
 
 =head1 SYNOPSIS
 
@@ -29,27 +29,27 @@ L<Algorithm::Evolutionary::Op::Base|Algorithm::Evolutionary::Op::Base>
 
 =head1 DESCRIPTION
 
-Crossover operator for a  individual with vector (array) representation
+Crossover operator for a  individual with vector representation
 
 =cut
 
 package Algorithm::Evolutionary::Op::VectorCrossover;
 
-our ($VERSION) = ( '$Revision: 3.1 $ ' =~ / (\d+\.\d+)/ );
+our ($VERSION) = ( '$Revision: 1.1.1.1 $ ' =~ /(\d+\.\d+)/ );
 
 use Carp;
-use Clone qw(clone);
 
-use base 'Algorithm::Evolutionary::Op::Base';
+use Algorithm::Evolutionary::Op::Base;
+our @ISA = ('Algorithm::Evolutionary::Op::Base');
 
 #Class-wide constants
 our $APPLIESTO =  'Algorithm::Evolutionary::Individual::Vector';
 our $ARITY = 2;
 
-=head2 new( [$number_of_crossing_points = 2], [$priority_rate = 1] )
+=head2 new
 
 Creates a new 1 or 2 point crossover operator. But this is just to have a non-empty chromosome
-Defaults to 2 point crossover
+Defaults to 2 point
 
 =cut
 
@@ -61,10 +61,10 @@ sub new {
   return $self;
 }
 
-=head2 create( [$number_of_crossing_points = 2] )
+=head2 create
 
 Creates a new 1 or 2 point crossover operator. But this is just to have a non-empty chromosome
-Defaults to 2 point. 
+Defaults to 2 point
 
 =cut
 
@@ -76,41 +76,41 @@ sub create {
   return $self;
 }
 
-=head2 apply( $chromosome_1, $chromosome_2 )
+=head2 apply
 
 Applies xover operator to a "Chromosome",  a vector of stuff,
 really. Can be applied only to I<victims> with the C<_array> instance
 variable; but it checks before application that both operands are of
-type L<Algorithm::Evolutionary::Individual::Vector|Algorithm::Evolutionary::Individual::Vector>. 
+type L<Algorithm::Evolutionary::Individual::Vector|Algorithm::Evolutionary::Individual::Vector>.
 
 =cut
 
 sub  apply ($$;$){
   my $self = shift;
-  my $arg = shift || croak "No victim here!";
-  my $victim = clone($arg);
+  my $victim = shift || croak "No victim here!";
   my $victim2 = shift || croak "No victim here!";
-  croak "Incorrect type ".(ref $victim) if !$victim->{'_array'};
-  croak "Incorrect type ".(ref $victim2) if !$victim2->{'_array'};
-  if ( (scalar @{$victim->{'_array'}} == 2) || (scalar @{$victim2->{'_array'}} == 2 ) ) {
+  croak "Incorrect type ".(ref $victim) if !$self->check($victim);
+  croak "Incorrect type ".(ref $victim2) if !$self->check($victim2);
+  if ( (scalar @{$victim->{_array}} == 2) || (scalar @{$victim2->{_array}} == 2 ) ) {
     #Too small, don't pay attention to number of cutting points
     my $i = (rand() > 0.5 )? 0:1;
-    $victim->{'_array'}[$i] =  $victim2->{'_array'}[$i];
+    $victim->{_array}[$i] =  $victim2->{_array}[$i];
   } else {
-    my $pt1 = int( rand( @{$victim->{'_array'}} - 1 ) ) ; #in int env; contains $# +1
+    my $pt1 = int( rand( @{$victim->{_array}} - 1 ) ) ; #in int env; contains $# +1
     
-    my $possibleRange = @{$victim->{'_array'}} - $pt1 - 1;
+    my $possibleRange = @{$victim->{_array}} - $pt1 - 1;
     my $range;
-    if ( $self->{'_numPoints'} > 1 ) {
+    if ( $self->{_numPoints} > 1 ) {
       $range = 1+ int ( rand( $possibleRange ) );
     } else {
       $range = $possibleRange + 1;
     }
+#    print "Puntos: $pt1, $possibleRange, $range \n";
     #Check length to avoid unwanted lengthening
-    return $victim if ( ( $pt1+$range >= @{$victim->{'_array'}} ) || ( $pt1+$range >= @{$victim2->{'_array'}} ));
+    return $victim if ( ( $pt1+$range >= @{$victim->{_array}} ) || ( $pt1+$range >= @{$victim2->{_array}} ));
     
-    @{$victim->{'_array'}}[$pt1..($pt1+$range)] =  
-      @{$victim2->{'_array'}}[$pt1..($pt1+$range)];
+    @{$victim->{_array}}[$pt1..($pt1+$range)] =  
+      @{$victim2->{_array}}[$pt1..($pt1+$range)];
     $victim->Fitness( undef ); #It's been changed, so fitness is invalid
   }
   return $victim;
@@ -121,10 +121,10 @@ sub  apply ($$;$){
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2012/12/08 10:06:23 $ 
-  $Header: /media/Backup/Repos/opeal/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/VectorCrossover.pm,v 3.1 2012/12/08 10:06:23 jmerelo Exp $ 
+  CVS Info: $Date: 2008/02/12 17:49:39 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/VectorCrossover.pm,v 1.1.1.1 2008/02/12 17:49:39 jmerelo Exp $ 
   $Author: jmerelo $ 
-  $Revision: 3.1 $
+  $Revision: 1.1.1.1 $
   $Name $
 
 =cut
